@@ -22,7 +22,7 @@ package MongoDB;
 # ABSTRACT: Official MongoDB Driver for Perl
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 # regexp_pattern was unavailable before 5.10, had to be exported to load the
 # function implementation on 5.10, and was automatically available in 5.10.1
@@ -103,7 +103,7 @@ MongoDB - Official MongoDB Driver for Perl
 
 =head1 VERSION
 
-version v0.999.998.4
+version v0.999.998.5
 
 This is the Alpha 4 release for v1.0.0.0.
 
@@ -272,6 +272,12 @@ classes may return other objects for specific features or functions.
 See the documentation of those classes for more details or the
 L<MongoDB Perl Driver Tutorial|MongoDB::Tutorial> for an example.
 
+=head2 Error handling
+
+Unless otherwise documented, errors result in fatal exceptions.  See
+L<MongoDB::Error> for a list of exception classes and error code
+constants.
+
 =head1 METHODS
 
 =head2 connect
@@ -371,7 +377,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrew Page Andrey Khozov Ashley Willis Ask Bjørn Hansen Brendan W. McAdams Casey Rojas Christian Sturm Colin Cyr danny David Morrison Nadle Steinbrunner Storch D. Ilmari Mannsåker Eric Daniels Gerard Goossen Graham Barr Jason Carey Toffaletti Johann Rolschewski Joseph Harnish Joshua Juran J. Stewart Kamil Slowikowski Ken Williams mapbuh Matthew Shopsin Michael Langner Rotmanov Mike Dirolf nightlord nightsailer Nuno Carvalho Orlando Vazquez Othello Maurer Robin Lee Roman Yerin Ronald J Kimball Stephen Oberholtzer Steve Sanbeg Stuart Watt Uwe Voelker Whitney.Jackson Xtreak
+=for stopwords Andrew Page Andrey Khozov Ashley Willis Ask Bjørn Hansen Brendan W. McAdams Casey Rojas Christian Sturm Colin Cyr danny David Morrison Nadle Steinbrunner Storch D. Ilmari Mannsåker Eric Daniels Gerard Goossen Glenn Fowler Graham Barr Jason Carey Toffaletti Johann Rolschewski Joseph Harnish Joshua Juran J. Stewart Kamil Slowikowski Ken Williams mapbuh Matthew Shopsin Michael Langner Rotmanov Mike Dirolf nightlord nightsailer Nuno Carvalho Orlando Vazquez Othello Maurer Robin Lee Roman Yerin Ronald J Kimball Stephen Oberholtzer Steve Sanbeg Stuart Watt Uwe Voelker Whitney.Jackson Xtreak
 
 =over 4
 
@@ -441,6 +447,10 @@ Gerard Goossen <gerard@ggoossen.net>
 
 =item *
 
+Glenn Fowler <cebjyre@cpan.org>
+
+=item *
+
 Graham Barr <gbarr@pobox.com>
 
 =item *
