@@ -19,7 +19,7 @@ package MongoDB::BulkWrite;
 # ABSTRACT: MongoDB bulk write interface
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use MongoDB::Error;
 use MongoDB::OID;
@@ -118,15 +118,15 @@ sub _build__client {
 sub find {
     my ( $self, $doc ) = @_;
 
-    confess "find requires a criteria document. Use an empty hashref for no criteria."
+    MongoDB::UsageError->throw("find requires a criteria document. Use an empty hashref for no criteria.")
       unless defined $doc;
 
     unless ( @_ == 2 && ref $doc eq any(qw/HASH ARRAY Tie::IxHash/) ) {
-        confess "argument to find must be a single hashref, arrayref or Tie::IxHash";
+        MongoDB::UsageError->throw("argument to find must be a single hashref, arrayref or Tie::IxHash");
     }
 
     if ( ref $doc eq 'ARRAY' ) {
-        confess "array reference to find must have key/value pairs"
+        MongoDB::UsageError->throw("array reference to find must have key/value pairs")
           if @$doc % 2;
         $doc = {@$doc};
     }
@@ -154,11 +154,11 @@ sub insert {
     my ( $self, $doc ) = @_;
 
     unless ( @_ == 2 && ref $doc eq any(qw/HASH ARRAY Tie::IxHash/) ) {
-        confess "argument to insert must be a single hashref, arrayref or Tie::IxHash";
+        MongoDB::UsageError->throw("argument to insert must be a single hashref, arrayref or Tie::IxHash");
     }
 
     if ( ref $doc eq 'ARRAY' ) {
-        confess "array reference to insert must have key/value pairs"
+        MongoDB::UsageError->throw("array reference to insert must have key/value pairs")
           if @$doc % 2;
         $doc = Tie::IxHash->new(@$doc);
     }
@@ -209,14 +209,14 @@ sub insert {
 sub execute {
     my ( $self, $write_concern ) = @_;
     if ( $self->_executed ) {
-        MongoDB::Error->throw("bulk op execute called more than once");
+        MongoDB::UsageError->throw("bulk op execute called more than once");
     }
     else {
         $self->_executed(1);
     }
 
     unless ( $self->_count_writes ) {
-        MongoDB::Error->throw("no bulk ops to execute");
+        MongoDB::UsageError->throw("no bulk ops to execute");
     }
 
     $write_concern ||= $self->collection->write_concern;
@@ -249,7 +249,7 @@ MongoDB::BulkWrite - MongoDB bulk write interface
 
 =head1 VERSION
 
-version v0.999.998.4
+version v0.999.998.5
 
 =head1 SYNOPSIS
 
