@@ -19,7 +19,7 @@ package MongoDB::CommandResult;
 # ABSTRACT: MongoDB generic command result document
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use Moose;
 use MongoDB::Error;
@@ -29,13 +29,13 @@ use namespace::clean -except => 'meta';
 
 with 'MongoDB::Role::_LastError';
 
-#pod =attr result
+#pod =attr output
 #pod
-#pod Hash reference with the result of a database command
+#pod Hash reference with the output document of a database command
 #pod
 #pod =cut
 
-has result => (
+has output => (
     is       => 'ro',
     isa      => HashRef,
     required => 1,
@@ -61,12 +61,12 @@ has address => (
 
 sub last_code {
     my ($self) = @_;
-    my $result = $self->result;
-    if ( $result->{code} ) {
-        return $result->{code};
+    my $output = $self->output;
+    if ( $output->{code} ) {
+        return $output->{code};
     }
-    elsif ( $result->{lastErrorObject} ) {
-        return $result->{lastErrorObject}{code} || 0;
+    elsif ( $output->{lastErrorObject} ) {
+        return $output->{lastErrorObject}{code} || 0;
     }
     else {
         return 0;
@@ -82,7 +82,7 @@ sub last_code {
 sub last_errmsg {
     my ($self) = @_;
     for my $err_key (qw/$err err errmsg/) {
-        return $self->result->{$err_key} if exists $self->result->{$err_key};
+        return $self->output->{$err_key} if exists $self->output->{$err_key};
     }
     return "";
 }
@@ -95,7 +95,7 @@ sub last_errmsg {
 
 sub last_wtimeout {
     my ($self) = @_;
-    return !!$self->result->{wtimeout};
+    return !!$self->output->{wtimeout};
 }
 
 #pod =method assert
@@ -108,11 +108,14 @@ sub assert {
     my ($self, $default_class) = @_;
 
     $self->_throw_database_error( $default_class )
-        if ! $self->result->{ok};
+        if ! $self->output->{ok};
 
     return 1;
 }
 
+# deprecated
+sub result { shift->output }
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -129,18 +132,18 @@ MongoDB::CommandResult - MongoDB generic command result document
 
 =head1 VERSION
 
-version v0.999.998.4
+version v0.999.998.5
 
 =head1 DESCRIPTION
 
-This class encapsulates the results from a database command.  Currently, it is only
-available from the C<result> attribute of C<MongoDB::DatabaseError>.
+This class encapsulates the results from a database command.  Currently, it is
+only available from the C<result> attribute of C<MongoDB::DatabaseError>.
 
 =head1 ATTRIBUTES
 
-=head2 result
+=head2 output
 
-Hash reference with the result of a database command
+Hash reference with the output document of a database command
 
 =head2 address
 
@@ -164,6 +167,21 @@ True if a write concern timed out or false otherwise.
 
 Throws an exception if the command failed.
 
+=for Pod::Coverage result
+
+=head1 DEPRECATIONS
+
+The methods still exist, but are no longer documented.  In a future version
+they will warn when used, then will eventually be removed.
+
+=over 4
+
+=item *
+
+result
+
+=back
+
 =head1 AUTHORS
 
 =over 4
