@@ -20,12 +20,13 @@ package MongoDB::GridFS;
 # ABSTRACT: A file storage utility
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use MongoDB::GridFS::File;
 use DateTime 0.78; # drops dependency on bug-prone Math::Round
 use Digest::MD5;
 use Moose;
+use MongoDB::Error;
 use MongoDB::WriteConcern;
 use MongoDB::_Types -types;
 use Types::Standard -types;
@@ -298,7 +299,7 @@ sub insert {
     my ($self, $fh, $metadata, $options) = @_;
     $options ||= {};
 
-    confess "not a file handle" unless $fh;
+    MongoDB::UsageError->throw("not a file handle") unless $fh;
     $metadata = {} unless $metadata && ref $metadata eq 'HASH';
 
     my $chunks =
@@ -339,7 +340,7 @@ sub insert {
         # get an md5 hash for the file. set the retry flag to 'true' incase the 
         # database, collection, or indexes are missing. That way we can recreate them 
         # retry the md5 calc.
-        my $result = $self->_calc_md5($chunks, $id, $self->prefix, 1);
+        my $result = $self->_database->run_command([filemd5 => $id, root => $self->prefix]);
         $copy{"md5"} = $result->{"md5"};
 
         my $md5 = Digest::MD5->new;
@@ -349,7 +350,8 @@ sub insert {
         if ($digest ne $result->{md5}) {
             # cleanup and die
             $chunks->delete_many({files_id => $id});
-            die "md5 hashes don't match: database got $result->{md5}, fs got $digest";
+            MongoDB::GridFSError->throw(
+                "md5 hashes don't match: database got $result->{md5}, fs got $digest" );
         }
     }
 
@@ -360,38 +362,6 @@ sub insert {
     return $files->insert_one(\%copy)->inserted_id;
 }
 
-# Calculates the md5 of the file on the server
-# $chunks: collection object with correct write concern
-# $id    : reference to the object we want to hash
-# $root  : the namespace the file resides in
-# $retry : a flag which controls whether or not to retry the md5 calc. 
-#         (which is currently only if we are missing our indexes)
-sub _calc_md5 {
-    my ($self, $chunks, $id, $root, $retry) = @_;
-   
-    # Try to get an md5 hash for the file
-    my $result = $self->_database->run_command(["filemd5", $id, "root" => $self->prefix]);
-    
-    # If we didn't get a hash back, it means something is wrong (probably to do with gridfs's 
-    # indexes because its currently the only error that is thrown from the md5 class)
-    if (ref($result) ne 'HASH') {
-        # Yep, indexes are missing. If we have the $retry flag, lets create them calc the md5 again
-        # but we wont pass set the $retry flag again. We don't want an infinite loop for any reason. 
-        if ($retry == 1 && $result eq 'need an index on { files_id : 1 , n : 1 }'){
-            $self->_ensure_indexes();
-            $result = $self->_calc_md5($chunks, $id, $root, 0);
-        }
-        # Well, something bad is happening, so lets clean up and die. 
-        else{
-            $chunks->delete_many({files_id => $id});
-            die "recieve an unexpected error from the server: $result";
-        }
-    }
-    
-    return $result;
-}
-
-
 #pod =method drop
 #pod
 #pod     $grid->drop;
@@ -466,7 +436,7 @@ MongoDB::GridFS - A file storage utility
 
 =head1 VERSION
 
-version v0.999.998.4
+version v0.999.998.5
 
 =head1 SYNOPSIS
 
