@@ -19,7 +19,7 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use Moose;
 use MongoDB;
@@ -726,7 +726,7 @@ sub BUILD {
 
     my @addresses = @{ $uri->hostpairs };
     if ( $self->connect_type eq 'direct' && @addresses > 1 ) {
-        confess "Connect type 'direct' cannot be used with multiple addresses: @addresses";
+        MongoDB::UsageError->throw("Connect type 'direct' cannot be used with multiple addresses: @addresses");
     }
 
     my $options = $uri->options;
@@ -758,10 +758,10 @@ sub BUILD {
 
 sub _str_to_bool {
     my $str = shift;
-    confess "cannot convert undef to bool" unless defined $str;
+    MongoDB::UsageError->throw("cannot convert undef to bool") unless defined $str;
     my $ret = $str eq "true" ? 1 : $str eq "false" ? 0 : undef;
     return $ret unless !defined $ret;
-    confess "expected boolean string 'true' or 'false' but instead received '$str'";
+    MongoDB::UsageError->throw("expected boolean string 'true' or 'false' but instead received '$str'");
 }
 
 #--------------------------------------------------------------------------#
@@ -897,14 +897,14 @@ sub database_names {
     my $max_tries = 3;
     for my $try ( 1 .. $max_tries ) {
         last if try {
-            my $result = $self->send_admin_command([ listDatabases => 1 ])->result;
-            if (ref($result) eq 'HASH' && exists $result->{databases}) {
-                @databases = map { $_->{name} } @{ $result->{databases} };
+            my $output = $self->send_admin_command([ listDatabases => 1 ])->output;
+            if (ref($output) eq 'HASH' && exists $output->{databases}) {
+                @databases = map { $_->{name} } @{ $output->{databases} };
             }
             return 1;
         } catch {
             # can't open db in a read lock
-            return if $_->{result}->{result}{code} == CANT_OPEN_DB_IN_READ_LOCK() || $try < $max_tries;
+            return if $_->result->ouput->{code} == CANT_OPEN_DB_IN_READ_LOCK() || $try < $max_tries;
             die $_;
         };
     }
@@ -965,10 +965,10 @@ sub get_database {
 
 sub get_namespace {
     my ( $self, $ns, $options ) = @_;
-    MongoDB::Error->throw("namespace requires a string argument")
+    MongoDB::UsageError->throw("namespace requires a string argument")
       unless defined($ns) && length($ns);
     my ( $db, $coll ) = split /\./, $ns, 2;
-    MongoDB::Error->throw("$ns is not a valid namespace")
+    MongoDB::UsageError->throw("$ns is not a valid namespace")
       unless defined($db) && defined($coll);
     return $self->db($db)->coll( $coll, $options );
 }
@@ -1082,7 +1082,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v0.999.998.4
+version v0.999.998.5
 
 =head1 SYNOPSIS
 
