@@ -19,7 +19,7 @@ package MongoDB::Op::_Command;
 # Encapsulate running a command and returning a MongoDB::CommandResult
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use Moose;
 
@@ -59,7 +59,7 @@ sub execute {
     $self->_apply_read_prefs( $link, $topology_type );
 
     my $res = MongoDB::CommandResult->new(
-        result  => $self->_send_command( $link, $self->query, $self->query_flags ),
+        output => $self->_send_command( $link, $self->query, $self->query_flags ),
         address => $link->address
     );
 
