@@ -19,7 +19,7 @@ package MongoDB::Op::_Distinct;
 # Encapsulate distinct operation; return MongoDB::QueryResult
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use Moose;
 
@@ -96,10 +96,10 @@ sub execute {
 
     my $res = $op->execute( $link, $topology );
 
-    $res->result->{cursor} = {
+    $res->output->{cursor} = {
         ns         => '',
         id         => 0,
-        firstBatch => ( delete $res->result->{values} ) || [],
+        firstBatch => ( delete $res->output->{values} ) || [],
     };
 
     return $self->_build_result_from_cursor($res);
