@@ -19,7 +19,7 @@ package MongoDB::QueryResult;
 # ABSTRACT: An iterator for Mongo query results
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use Moose;
 use MongoDB::Error;
@@ -306,7 +306,7 @@ __PACKAGE__->meta->make_immutable;
 #pod =head1 SYNOPSIS
 #pod
 #pod     $cursor = $coll->find( $filter );
-#pod     $resuilt = $cursor->result;
+#pod     $result = $cursor->result;
 #pod
 #pod     while ( $doc = $result->next ) {
 #pod         process_doc($doc)
@@ -356,12 +356,12 @@ MongoDB::QueryResult - An iterator for Mongo query results
 
 =head1 VERSION
 
-version v0.999.998.4
+version v0.999.998.5
 
 =head1 SYNOPSIS
 
     $cursor = $coll->find( $filter );
-    $resuilt = $cursor->result;
+    $result = $cursor->result;
 
     while ( $doc = $result->next ) {
         process_doc($doc)
