@@ -19,9 +19,10 @@ package MongoDB::ReadPreference;
 # ABSTRACT: Encapsulate and validate read preferences
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use Moose;
+use MongoDB::Error;
 use MongoDB::_Types -types;
 use Types::Standard -types;
 use namespace::clean -except => 'meta';
@@ -73,7 +74,7 @@ sub BUILD {
     my ($self) = @_;
 
     if ( $self->mode eq 'primary' && !$self->has_empty_tag_sets ) {
-        confess "A tag set list is not allowed with read preference mode 'primary'";
+        MongoDB::UsageError->throw("A tag set list is not allowed with read preference mode 'primary'");
     }
 
     return;
@@ -127,7 +128,7 @@ MongoDB::ReadPreference - Encapsulate and validate read preferences
 
 =head1 VERSION
 
-version v0.999.998.4
+version v0.999.998.5
 
 =head1 SYNOPSIS
 
