@@ -19,7 +19,7 @@ package MongoDB::Role::_CommandCursorOp;
 # MongoDB interface for database commands with cursors
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use MongoDB::Error;
 use MongoDB::QueryResult;
@@ -32,7 +32,7 @@ requires 'client';
 sub _build_result_from_cursor {
     my ( $self, $res ) = @_;
 
-    my $cursor = $res->result->{cursor}
+    my $cursor = $res->output->{cursor}
       or MongoDB::DatabaseError->throw(
         message => "no cursor found in command response",
         result  => $res,
