@@ -17,9 +17,10 @@
 package MongoDB::_Credential;
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
 
 use Moose;
+use MongoDB::Error;
 use MongoDB::Op::_Command;
 use MongoDB::_Types -types;
 
@@ -153,7 +154,7 @@ sub BUILD {
     while ( my ( $key, $validator ) = each %{ $CONSTRAINTS{$mech} } ) {
         local $_ = $self->$key;
         unless ( $validator->() ) {
-            MongoDB::Error->throw("invalid field $key ('$_') in $mech credential");
+            MongoDB::UsageError->throw("invalid field $key ('$_') in $mech credential");
         }
     }
 
@@ -188,7 +189,7 @@ sub _authenticate_NONE () { 1 }
 sub _authenticate_MONGODB_CR {
     my ( $self, $link ) = @_;
 
-    my $nonce = $self->_send_command( $link, 'admin', { getnonce => 1 } )->result->{nonce};
+    my $nonce = $self->_send_command( $link, 'admin', { getnonce => 1 } )->output->{nonce};
     my $key =
       md5_hex( encode( "UTF-8", $nonce . $self->username . $self->_digested_password ) );
 
@@ -230,7 +231,7 @@ sub _authenticate_GSSAPI {
     my ( $self, $link ) = @_;
 
     eval { require Authen::SASL; 1 }
-      or MongoDB::Error->throw(
+      or MongoDB::AuthError->throw(
         "GSSAPI requires Authen::SASL and GSSAPI or Authen::SASL::XS from CPAN");
 
     my ( $sasl, $client );
@@ -246,7 +247,7 @@ sub _authenticate_GSSAPI {
           $sasl->client_new( $self->mechanism_properties->{SERVICE_NAME}, $link->{host} );
     }
     catch {
-        MongoDB::Error->throw(
+        MongoDB::AuthError->throw(
             "Failed to initialize a GSSAPI backend (did you install GSSAPI or Authen::SASL::XS?) Error was: $_"
         );
     };
@@ -267,7 +268,7 @@ sub _authenticate_GSSAPI {
         }
     }
     catch {
-        MongoDB::Error->throw("GSSAPI error: $_");
+        MongoDB::AuthError->throw("GSSAPI error: $_");
     };
 
     return 1;
@@ -289,7 +290,7 @@ sub _authenticate_SCRAM_SHA_1 {
         $self->_sasl_continue( $link, "", $conv_id ) if !$done;
     }
     catch {
-        MongoDB::Error->throw("SCRAM-SHA-1 error: $_");
+        MongoDB::AuthError->throw("SCRAM-SHA-1 error: $_");
     };
 
     return 1;
@@ -308,13 +309,13 @@ sub _assert_gssapi {
         my $code = $client->code;
         if ( $code != 0 && $code != 1 ) { # not OK or CONTINUE
             my $error = join( "; ", $client->error );
-            MongoDB::Error->throw("$prefix$error");
+            MongoDB::AuthError->throw("$prefix$error");
         }
     }
     else {
         # Authen::SASL::Perl::GSSAPI or some unknown backend
         if ( my $error = $client->error ) {
-            MongoDB::Error->throw("$prefix$error");
+            MongoDB::AuthError->throw("$prefix$error");
         }
     }
 
@@ -348,10 +349,10 @@ sub _sasl_continue {
 
 sub _sasl_send {
     my ( $self, $link, $command ) = @_;
-    my $result = $self->_send_command( $link, $self->source, $command )->result;
+    my $output = $self->_send_command( $link, $self->source, $command )->output;
 
-    my $sasl_resp = $result->{payload} ? decode_base64( $result->{payload} ) : "";
-    return ( $sasl_resp, $result->{conversationId}, $result->{done} );
+    my $sasl_resp = $output->{payload} ? decode_base64( $output->{payload} ) : "";
+    return ( $sasl_resp, $output->{conversationId}, $output->{done} );
 }
 
 sub _send_command {
