@@ -21,7 +21,9 @@ use warnings;
 package MongoDB::_Protocol;
 
 use version;
-our $VERSION = 'v0.999.998.4'; # TRIAL
+our $VERSION = 'v0.999.998.5';
+
+use MongoDB::Error;
 
 use constant {
     OP_REPLY        => 1,    # Reply to a client request. responseTo is set
